# Geopypi


[![image](https://img.shields.io/pypi/v/Geopypi.svg)](https://pypi.python.org/pypi/Geopypi)
[![image](https://img.shields.io/conda/vn/conda-forge/Geopypi.svg)](https://anaconda.org/conda-forge/Geopypi)


**This is a python package for batch geoprocessing.**


-   Free software: MIT License
-   Documentation: https://Metaliguns77.github.io/Geopypi
    

## Features

-   TODO
